@@ -55,6 +55,7 @@ class UpdatePrepare(DeployOvercloud):
 
     def take_action(self, parsed_args):
         self.log.debug("take_action(%s)" % parsed_args)
+        oooutils.ensure_run_as_normal_user()
 
         if (not parsed_args.yes
                 and not oooutils.prompt_user_for_confirmation(
@@ -168,18 +169,11 @@ class UpdateRun(command.Command):
             help=_("Use -y or --yes to skip the confirmation required before "
                    "any update operation. Use this with caution! "),
         )
-        parser.add_argument(
-            '--ansible-forks',
-            action='store',
-            default=None,
-            type=int,
-            help=_('The number of Ansible forks to use for the'
-                   ' config-download ansible-playbook command.')
-        )
         return parser
 
     def take_action(self, parsed_args):
         self.log.debug("take_action(%s)" % parsed_args)
+        oooutils.ensure_run_as_normal_user()
 
         if (not parsed_args.yes
             and not oooutils.prompt_user_for_confirmation(
@@ -218,8 +212,7 @@ class UpdateRun(command.Command):
                 limit_nodes=parsed_args.limit
             ),
             skip_tags=parsed_args.skip_tags,
-            tags=parsed_args.tags,
-            forks=parsed_args.ansible_forks
+            tags=parsed_args.tags
         )
         self.log.info("Completed Overcloud Minor Update Run.")
 
@@ -245,6 +238,7 @@ class UpdateConverge(DeployOvercloud):
 
     def take_action(self, parsed_args):
         self.log.debug("take_action(%s)" % parsed_args)
+        oooutils.ensure_run_as_normal_user()
 
         if (not parsed_args.yes
             and not oooutils.prompt_user_for_confirmation(
