@@ -238,14 +238,6 @@ class TripleOValidatorRun(command.Command):
                 " run invocation. For example: --limit \"compute-0,"
                 " compute-1, compute-5\".")
         )
-        parser.add_argument('--playbook',
-                            nargs="*",
-                            default=None,
-                            help=_("List of Ansible playbook to use for "
-                                   "validations. It could be a playbook path "
-                                   "or a list of playbook.")
-                            )
-
         extra_vars_group = parser.add_mutually_exclusive_group(required=False)
 
         extra_vars_group.add_argument(
@@ -282,6 +274,17 @@ class TripleOValidatorRun(command.Command):
                 "ANSIBLE_STDOUT_CALLBACK=default")
         )
 
+        extra_vars_group.add_argument(
+            '--static-inventory',
+            action='store',
+            default='',
+            help=_(
+                "Provide your own static inventory file. You can generate "
+                "such an inventory calling tripleo-ansible-inventory command. "
+                "Especially useful when heat service isn't available."
+            )
+        )
+
         ex_group = parser.add_mutually_exclusive_group(required=True)
 
         ex_group.add_argument(
@@ -314,7 +317,6 @@ class TripleOValidatorRun(command.Command):
     def _run_validator_run(self, parsed_args):
         LOG = logging.getLogger(__name__ + ".ValidationsRunAnsible")
         limit = parsed_args.limit
-        playbook = parsed_args.playbook
         extra_vars = parsed_args.extra_vars
         if parsed_args.extra_vars_file:
             with open(parsed_args.extra_vars_file, 'r') as env_file:
@@ -323,17 +325,22 @@ class TripleOValidatorRun(command.Command):
                 else:
                     extra_vars.update(yaml.load(env_file))
 
-        static_inventory = oooutils.get_tripleo_ansible_inventory(
-            ssh_user='heat-admin',
-            stack=parsed_args.plan,
-            undercloud_connection='local',
-            return_inventory_file_path=True)
+        # We don't check if the file exists in order to support
+        # passing a string such as "localhost,", like we can do with
+        # the "-i" option of ansible-playbook.
+        if parsed_args.static_inventory:
+            static_inventory = parsed_args.static_inventory
+        else:
+            static_inventory = oooutils.get_tripleo_ansible_inventory(
+                ssh_user='heat-admin',
+                stack=parsed_args.plan,
+                undercloud_connection='local',
+                return_inventory_file_path=True)
 
         v_consts.DEFAULT_VALIDATIONS_BASEDIR = constants.\
             DEFAULT_VALIDATIONS_BASEDIR
         actions = ValidationActions()
         results = actions.run_validations(
-            playbook=(playbook if playbook else []),
             inventory=static_inventory,
             limit_hosts=limit,
             group=parsed_args.group,
@@ -364,9 +371,10 @@ class TripleOValidatorRun(command.Command):
             t.add_row(r.values())
         print(t)
 
-        LOG.debug(_('Removing static tripleo ansible inventory file'))
-        oooutils.cleanup_tripleo_ansible_inventory_file(
-            static_inventory)
+        if not parsed_args.static_inventory:
+            LOG.debug(_('Removing static tripleo ansible inventory file'))
+            oooutils.cleanup_tripleo_ansible_inventory_file(
+                static_inventory)
 
     def take_action(self, parsed_args):
         self._run_validator_run(parsed_args)
